@@ -65,11 +65,11 @@ install_latest <- function(source = c("development", "cran"),
     easy_pkgs <- .easystats_version()
     # for development versions, overwrite CRAN version with r-universe version
     for (i in packages) {
-      js <- jsonlite::fromJSON(paste0("https://easystats.r-universe.dev/packages/", i))
+      js <- jsonlite::fromJSON(paste0("https://easystats.r-universe.dev/api/packages/", i))
       easy_pkgs$cran[easy_pkgs$package == i] <- js$Version[1]
     }
     easy_pkgs$behind <- package_version(easy_pkgs$cran) > package_version(easy_pkgs$local)
-    packages <- easy_pkgs$package[packages %in% easy_pkgs$package & easy_pkgs$behind]
+    packages <- easy_pkgs$package[easy_pkgs$behind[stats::na.omit(match(packages, easy_pkgs$package))]]
 
     if (isTRUE(verbose) && !is.null(packages) && length(packages)) {
       colnames(easy_pkgs) <- c("Package", "Latest", "Installed", "behind")
